pub enum IconTheme {
Dark,
Light,
}Expand description
Represents the theme the icon is designed for.
Variants
Dark
The icon is designed for use with a dark background.
Light
The icon is designed for use with a light background.