pub struct EmptyResourceContents {
pub uri: Uri,
pub title: Option<String>,
pub mime: Option<String>,
pub annotations: Option<Annotations>,
pub meta: Option<Value>,
}Expand description
Represents an empty/unknown resource content
Fields
uri: UriThe URI of the resource.
title: Option<String>Intended for UI and end-user contexts - optimized to be human-readable and easily understood, even by those unfamiliar with domain-specific terminology.
If not provided, the name should be used for display (except for Tool,
where annotations.title should be given precedence over using name, if present).
mime: Option<String>The MIME type of content.
annotations: Option<Annotations>Optional annotations for the client.
meta: Option<Value>Metadata reserved by MCP for protocol-level metadata.
Implementations
Sourceimpl EmptyResourceContents
impl EmptyResourceContents
Sourcepub fn with_mime(self, mime: impl Into<String>) -> Self
pub fn with_mime(self, mime: impl Into<String>) -> Self
Sets the mime type of the blob resource content
Sourcepub fn with_title(self, title: impl Into<String>) -> Self
pub fn with_title(self, title: impl Into<String>) -> Self
Sets the title of the resource
Sourcepub fn with_annotations<F>(self, config: F) -> Self
pub fn with_annotations<F>(self, config: F) -> Self
Sets annotations for the client