ToolUse

Struct ToolUse 

pub struct ToolUse {
    pub id: String,
    pub name: String,
    pub input: Option<HashMap<String, Value>>,
    pub meta: Option<Value>,
}
Represents a request from the assistant to call a tool.

See the schema for details

Fields

id: String

A unique identifier for this tool use.

This ID is used to match tool results to their corresponding tool uses.

name: String

The name of the tool to call.

input: Option<HashMap<String, Value>>

The arguments to pass to the tool, conforming to the tool’s input schema.

meta: Option<Value>

Metadata reserved by MCP for protocol-level metadata.

Implementations

Source

impl ToolUse

pub fn new<N, Args>(name: N, args: Args) -> Self
where N: Into<String>, Args: IntoArgs,

Creates a new ToolUse content