Task

Struct Task 

pub struct Task {
    pub id: String,
    pub created_at: DateTime<Utc>,
    pub last_updated_at: DateTime<Utc>,
    pub ttl: usize,
    pub status: TaskStatus,
    pub status_msg: Option<String>,
    pub poll_interval: Option<usize>,
}
Represents a task. Tasks are durable state machines that carry information about the underlying execution state of the request they wrap, and are intended for requestor polling and deferred result retrieval.

Each task is uniquely identifiable by a receiver-generated task ID.

See the schema for details

Fields

id: String

The task identifier.

created_at: DateTime<Utc>

ISO 8601 timestamp when the task was created.

last_updated_at: DateTime<Utc>

ISO 8601 timestamp when the task was last updated.

ttl: usize

Time To Live: Actual retention duration from creation in milliseconds, null for unlimited.

status: TaskStatus

Current task state.

status_msg: Option<String>

Optional human-readable message describing the current task state. This can provide context for any status, including

  • Reasons for cancelled status
  • Summaries for completed status
  • Diagnostic information for failed status (e.g., error details, what went wrong)
poll_interval: Option<usize>

Suggested polling interval in milliseconds.

Implementations

Source

impl Task

pub fn new() -> Self

Creates a new Task in working status and with a default TTL of 30 seconds.

pub fn set_message(&mut self, msg: impl Into<String>)

Sets the status message of the task.

pub fn reset(&mut self)

Sets the working status.

pub fn cancel(self) -> Self

Sets the cancelled status.

pub fn complete(&mut self)

Sets the completed status.

pub fn fail(&mut self)

Sets the failed status.

pub fn require_input(&mut self)

Sets the input_required status.