pub struct ListToolsRequestParams {
pub cursor: Option<Cursor>,
}Expand description
Sent from the client to request a list of tools the server has.
See the schema for details
Fields
cursor: Option<Cursor>An opaque token representing the current pagination position. If provided, the server should return results starting after this cursor.