pub struct Task {
pub id: String,
pub created_at: DateTime<Utc>,
pub last_updated_at: DateTime<Utc>,
pub ttl: usize,
pub status: TaskStatus,
pub status_msg: Option<String>,
pub poll_interval: Option<usize>,
}Expand description
Represents a task. Tasks are durable state machines that carry information about the underlying execution state of the request they wrap, and are intended for requestor polling and deferred result retrieval.
Each task is uniquely identifiable by a receiver-generated task ID.
See the schema for details
Fields
id: StringThe task identifier.
created_at: DateTime<Utc>ISO 8601 timestamp when the task was created.
last_updated_at: DateTime<Utc>ISO 8601 timestamp when the task was last updated.
ttl: usizeTime To Live: Actual retention duration from creation in milliseconds, null for unlimited.
status: TaskStatusCurrent task state.
status_msg: Option<String>Optional human-readable message describing the current task state. This can provide context for any status, including
- Reasons for
cancelledstatus - Summaries for
completedstatus - Diagnostic information for
failedstatus (e.g., error details, what went wrong)
poll_interval: Option<usize>Suggested polling interval in milliseconds.
Implementations